Mp4Worker class

Inheritance

Constructors

Mp4Worker({required Dio dio, required M3u8Task task, void onProgress(M3u8Task)?, void onDone(M3u8Task)?, Mp4RefreshUrl? refreshUrl})

Properties

dio → Dio
final
hashCode int
The hash code for this object.
no setterinherited
onDone → void Function(M3u8Task)?
final
onProgress → void Function(M3u8Task)?
final
refreshUrl Mp4RefreshUrl?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
task M3u8Task
final

Methods

cancel({bool deleteFiles = false}) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
override
start() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited